@@ -470,11 +470,6 @@ static void zeroBuffers (struct b_whirl *w) {
 	memset(w->adx0, 0, sizeof(float) * AGBUF);
 	memset(w->adx1, 0, sizeof(float) * AGBUF);
 	memset(w->adx2, 0, sizeof(float) * AGBUF);
-
-	memset(w->HLbuf, 0, WHIRL_BUF_SIZE_SAMPLES);
-	memset(w->HRbuf, 0, WHIRL_BUF_SIZE_SAMPLES);
-	memset(w->DLbuf, 0, WHIRL_BUF_SIZE_SAMPLES);
-	memset(w->DRbuf, 0, WHIRL_BUF_SIZE_SAMPLES);
 }
 
 void computeOffsets (struct b_whirl *w) {
@@ -1009,7 +1004,7 @@ int whirlConfig (struct b_whirl *w, ConfigContext * cfg) {
 
 #ifdef __ARMEL__
 static inline float x_mod1 (const float f) {
-	return ((unsigned int)(f * 65536.f) & 65535) / 65536.f;
+	return ((unsigned int)(f * 8388608.f) & 8388607) / 8388608.f; // 2^23
 }
 
 static inline unsigned int x_iroundf (const float f) {
