@@ -26,12 +26,17 @@
 #include "../src/cfgParser.h" // ConfigContext
 #include "../src/midi.h" // useMIDIControlFunction
 
-#define WHIRL_DISPLC_SIZE ((unsigned int) (1 << 11))
+#define WHIRL_DISPLC_SIZE ((unsigned int) (1 << 14))
 #define WHIRL_DISPLC_MASK ((WHIRL_DISPLC_SIZE) - 1)
 
-#define WHIRL_BUF_SIZE_SAMPLES ((unsigned int) (1 << 11))
+#define WHIRL_BUF_SIZE_SAMPLES ((unsigned int) (1 << 10))
 #define WHIRL_BUF_MASK_SAMPLES (WHIRL_BUF_SIZE_SAMPLES - 1)
 
+#define AGBUF 8
+#define AGMASK (AGBUF-1)
+
+typedef float iir_t;
+
 typedef enum {a0, a1, a2, b0, b1, b2, z0, z1} filterCoeff;
 
 typedef struct _revcontrol {
@@ -45,8 +50,8 @@ struct b_whirl {
 
   double SampleRateD;
   int bypass;        ///< if set to 1 completely bypass this effect
-  double hnBreakPos; ///< where to stop horn - 0: free, 1.0: front-center, ]0..1] clockwise circle */
-  double drBreakPos; ///< where to stop drum
+  double hnBrakePos; ///< where to stop horn - 0: free, 1.0: front-center, ]0..1] clockwise circle */
+  double drBrakePos; ///< where to stop drum
 
 /*
  * Forward (clockwise) displacement table for writing positions.
@@ -63,9 +68,6 @@ struct b_whirl {
   struct _bw bfw[WHIRL_DISPLC_SIZE];
   struct _bw bbw[WHIRL_DISPLC_SIZE];
 
-#define AGBUF 512
-#define AGMASK (AGBUF-1)
-
   float adx0[AGBUF];
   float adx1[AGBUF];
   float adx2[AGBUF];
@@ -91,6 +93,8 @@ struct b_whirl {
   double hornAngleGRD;  /* 0..1 */
   double drumAngleGRD;
 
+  double micAngle;
+
 /* target speed - rotational frequency */
   float hornRPMslow;
   float hornRPMfast;
@@ -111,8 +115,8 @@ struct b_whirl {
   int hornAcDc;
   int drumAcDc;
 
-  double hornIncrGRD; ///< current angular speed - unit: radians / sample / (2*M_PI)
-  double drumIncrGRD; ///< current angular speed - unit: radians / sample / (2*M_PI)
+  double hornIncr; ///< current angular speed - unit: radians / sample / (2*M_PI)
+  double drumIncr; ///< current angular speed - unit: radians / sample / (2*M_PI)
 
   double hornTarget; ///< target angular speed  - unit: radians / sample / (2*M_PI)
   double drumTarget; ///< target angular speed  - unit: radians / sample / (2*M_PI)
@@ -128,6 +132,8 @@ struct b_whirl {
 
   float airSpeed;	/* Meters per second */
   float micDistCm;	/* From mic to origin */
+  float hornXOffsetCm;	/* offset of horn, towards left mic */
+  float hornZOffsetCm;	/* offset of horn, perpendicular to mic to front */
   float drumSpacing[6];
 
 /* Delay buffers */
@@ -142,20 +148,20 @@ struct b_whirl {
   unsigned int outpos;
   float z[4];
 
-  float drfL[8];/* Drum filter */
-  float drfR[8];/* Drum filter */
+  iir_t  drfL[8];/* Drum filter */
+  iir_t  drfR[8];/* Drum filter */
   int    lpT;	/* high shelf */
   double lpF;	/* Frequency */
   double lpQ;	/* Q, bandwidth */
   double lpG;	/* Gain */
 
-  float hafw[8];		/* Horn filter a */
+  iir_t hafw[8]; /* Horn filter a */
   float haT; /* low pass */
   float haF; /* 3900.0; 25-nov-04 */
   float haQ; /*   1.4; 25-nov-04 */
   float haG; /*   0.0; 25-nov-04 */
 
-  float hbfw[8];
+  iir_t hbfw[8];
   float hbT;		/* low shelf */
   float hbF;
   float hbQ; /* 2.0; 25-nov-04 */
@@ -191,6 +197,12 @@ struct b_whirl {
   float leakLevel;
   float leakage;
 
+  float drumMicWidth, hornMicWidth;
+  float drumMic_dll, hornMic_hll;
+  float drumMic_dlr, hornMic_hlr;
+  float drumMic_drl, hornMic_hrl;
+  float drumMic_drr, hornMic_hrr;
+
   void *midi_cfg_ptr;
 
 };
@@ -215,6 +227,12 @@ extern void whirlProc2 (struct b_whirl *w,
 		        float * outDL, float * outDR,
 		        size_t bufferLengthSamples);
 
+extern void whirlProc3 (struct b_whirl *w,
+			const float * inbuffer,
+		        float * outL, float * outR,
+		        float * tmpL, float * tmpR,
+		        size_t bufferLengthSamples);
+
 #define WHIRL_FAST 2
 #define WHIRL_SLOW 1
 #define WHIRL_STOP 0
@@ -234,5 +252,8 @@ extern void fsetDrumFilterFrequency (struct b_whirl *w, float v);
 extern void fsetDrumFilterQ (struct b_whirl *w, float v);
 extern void fsetDrumFilterGain (struct b_whirl *w, float v);
 extern void computeRotationSpeeds (struct b_whirl *w);
+extern void computeOffsets (struct b_whirl *w);
+extern void fsetDrumMicWidth (void *d, const float dw);
+
 #endif /* WHIRL_H */
 /* vi:set ts=8 sts=2 sw=2: */
