@@ -40,6 +40,6 @@ extern int mainConfig (ConfigContext * cfg);
 extern const ConfigDoc *mainDoc ();
 
 extern double SampleRateD; // TODO -> tonegen.c, vibrato.c non-global
-extern void save_midname(void *instp, FILE *f); // defined in midnam.c
+extern void save_midname(void *instp, FILE *f, char* model); // defined in midnam.c
 
 #endif /* MAIN_H */
