@@ -25,7 +25,7 @@ void *allocRunningConfig(void);
 void initRunningConfig(void *t, void *mcfg);
 void freeRunningConfig(void *t);
 
-void rc_add_midicc(void *t, int id, unsigned short val);
+void rc_add_midicc(void *t, int id, unsigned char val);
 void rc_add_cfg(void *t, ConfigContext *cfg);
 
 void rc_loop_state(void *t, void (*cb)(int, const char *, const char *, unsigned char, void *), void *arg);
